.. _utilipy-decorators-docstring:

*****************************************************
Docstring Decorators (`utilipy.decorators.docstring`)
*****************************************************

.. currentmodule:: utilipy.decorators.docstring



Reference/API
=============

.. automodapi:: utilipy.decorators.docstring
